@@ -2,7 +2,7 @@ from os import makedirs
 from os.path import isdir
 from abc import ABC, abstractmethod
 from pathlib import Path
-from abstract.finite_automaton import FiniteAutomaton
+from pythautomata.abstract.finite_automaton import FiniteAutomaton
 
 
 class ModelExportingStrategy(ABC):
