@@ -1,10 +1,10 @@
-from base_types.state import State
-from base_types.symbol import SymbolStr
-from base_types.alphabet import Alphabet
-from automata.deterministic_finite_automaton import DeterministicFiniteAutomaton as DFA
-from automata.non_deterministic_finite_automaton import NondeterministicFiniteAutomaton as NFA
-from model_comparators.nfa_hopcroft_karp_comparison_strategy import NFAHopcroftKarpComparisonStrategy as NFAComparator
-from model_comparators.dfa_comparison_strategy import DFAComparisonStrategy as DFAComparator
+from pythautomata.base_types.state import State
+from pythautomata.base_types.symbol import SymbolStr
+from pythautomata.base_types.alphabet import Alphabet
+from pythautomata.automata.deterministic_finite_automaton import DeterministicFiniteAutomaton as DFA
+from pythautomata.automata.non_deterministic_finite_automaton import NondeterministicFiniteAutomaton as NFA
+from pythautomata.model_comparators.nfa_hopcroft_karp_comparison_strategy import NFAHopcroftKarpComparisonStrategy as NFAComparator
+from pythautomata.model_comparators.dfa_comparison_strategy import DFAComparisonStrategy as DFAComparator
 
 binaryAlphabet = Alphabet(frozenset((SymbolStr('0'), SymbolStr('1'))))
 zero = binaryAlphabet['0']
