@@ -1,14 +1,14 @@
 from itertools import chain
 from unittest import TestCase
-from model_comparators.nfa_hopcroft_karp_comparison_strategy import NFAHopcroftKarpComparisonStrategy as NFAComparator
-from model_comparators.dfa_comparison_strategy import DFAComparisonStrategy as DFAComparator
-from automata_definitions.other_automata import OtherAutomata
-from automata_definitions.tomitas_grammars import TomitasGrammars
-from automata_definitions.omlin_giles_automata import OmlinGilesAutomata
-from automata_definitions.bollig_habermehl_kern_leucker_automata import BolligHabermehlKernLeuckerAutomata
-from automata.deterministic_finite_automaton import DeterministicFiniteAutomaton as DFA
-from automata.non_deterministic_finite_automaton import NondeterministicFiniteAutomaton as NFA
-from utilities.automata_convertor import AutomataConvertor
+from pythautomata.model_comparators.nfa_hopcroft_karp_comparison_strategy import NFAHopcroftKarpComparisonStrategy as NFAComparator
+from pythautomata.model_comparators.dfa_comparison_strategy import DFAComparisonStrategy as DFAComparator
+from pythautomata.automata_definitions.other_automata import OtherAutomata
+from pythautomata.automata_definitions.tomitas_grammars import TomitasGrammars
+from pythautomata.automata_definitions.omlin_giles_automata import OmlinGilesAutomata
+from pythautomata.automata_definitions.bollig_habermehl_kern_leucker_automata import BolligHabermehlKernLeuckerAutomata
+from pythautomata.automata.deterministic_finite_automaton import DeterministicFiniteAutomaton as DFA
+from pythautomata.automata.non_deterministic_finite_automaton import NondeterministicFiniteAutomaton as NFA
+from pythautomata.utilities.automata_convertor import AutomataConvertor
 
 
 class TestAutomataComparison(TestCase):
